@@ -176,7 +176,9 @@ def get_keychain(journal_name):
 
     try:
         return keyring.get_password("jrnl", journal_name)
-    except RuntimeError:
+    except keyring.errors.KeyringError as e:
+        if not isinstance(e, keyring.errors.NoKeyringError):
+            print("Failed to retrieve keyring", file=sys.stderr)
         return ""
 
 
@@ -186,13 +188,16 @@ def set_keychain(journal_name, password):
     if password is None:
         try:
             keyring.delete_password("jrnl", journal_name)
-        except keyring.errors.PasswordDeleteError:
+        except keyring.errors.KeyringError:
             pass
     else:
         try:
             keyring.set_password("jrnl", journal_name, password)
-        except keyring.errors.NoKeyringError:
-            print(
-                "Keyring backend not found. Please install one of the supported backends by visiting: https://pypi.org/project/keyring/",
-                file=sys.stderr,
-            )
+        except keyring.errors.KeyringError as e:
+            if isinstance(e, keyring.errors.NoKeyringError):
+                print(
+                    "Keyring backend not found. Please install one of the supported backends by visiting: https://pypi.org/project/keyring/",
+                    file=sys.stderr,
+                )
+            else:
+                print("Failed to retrieve keyring", file=sys.stderr)
