@@ -23,13 +23,13 @@ def deprecated_cmd(old_cmd, new_cmd, callback=None, **kwargs):
         callback(**kwargs)
 
 
-def list_journals(config):
-    from . import install
+def list_journals(configuration):
+    from . import config
 
     """List the journals specified in the configuration file"""
-    result = f"Journals defined in {install.CONFIG_FILE_PATH}\n"
-    ml = min(max(len(k) for k in config["journals"]), 20)
-    for journal, cfg in config["journals"].items():
+    result = f"Journals defined in {config.get_config_path()}\n"
+    ml = min(max(len(k) for k in configuration["journals"]), 20)
+    for journal, cfg in configuration["journals"].items():
         result += " * {:{}} -> {}\n".format(
             journal, ml, cfg["journal"] if isinstance(cfg, dict) else cfg
         )
