@@ -1,11 +1,11 @@
 # Copyright (C) 2012-2021 jrnl contributors
 # License: https://www.gnu.org/licenses/gpl-3.0.html
 
-from datetime import datetime
+import datetime
 
 FAKE_YEAR = 9999
-DEFAULT_FUTURE = datetime(FAKE_YEAR, 12, 31, 23, 59, 59)
-DEFAULT_PAST = datetime(FAKE_YEAR, 1, 1, 0, 0)
+DEFAULT_FUTURE = datetime.datetime(FAKE_YEAR, 12, 31, 23, 59, 59)
+DEFAULT_PAST = datetime.datetime(FAKE_YEAR, 1, 1, 0, 0)
 
 
 def __get_pdt_calendar():
@@ -27,7 +27,7 @@ def parse(
     """Parses a string containing a fuzzy date and returns a datetime.datetime object"""
     if not date_str:
         return None
-    elif isinstance(date_str, datetime):
+    elif isinstance(date_str, datetime.datetime):
         return date_str
 
     # Don't try to parse anything with 6 or less characters and was parsed from the existing journal.
@@ -44,7 +44,9 @@ def parse(
 
             date = dateparse(date_str, default=default_date)
             if date.year == FAKE_YEAR:
-                date = datetime(datetime.now().year, date.timetuple()[1:6])
+                date = datetime.datetime(
+                    datetime.datetime.now().year, date.timetuple()[1:6]
+                )
             else:
                 year_present = True
             flag = 1 if date.hour == date.minute == 0 else 2
@@ -52,7 +54,7 @@ def parse(
         except Exception as e:
             if e.args[0] == "day is out of range for month":
                 y, m, d, H, M, S = default_date.timetuple()[:6]
-                default_date = datetime(y, m, d - 1, H, M, S)
+                default_date = datetime.datetime(y, m, d - 1, H, M, S)
             else:
                 calendar = __get_pdt_calendar()
                 date, flag = calendar.parse(date_str)
@@ -60,26 +62,26 @@ def parse(
     if not flag:  # Oops, unparsable.
         try:  # Try and parse this as a single year
             year = int(date_str)
-            return datetime(year, 1, 1)
+            return datetime.datetime(year, 1, 1)
         except ValueError:
             return None
         except TypeError:
             return None
 
     if flag == 1:  # Date found, but no time. Use the default time.
-        date = datetime(
+        date = datetime.datetime(
             *date[:3],
             hour=23 if inclusive else default_hour or 0,
             minute=59 if inclusive else default_minute or 0,
             second=59 if inclusive else 0
         )
     else:
-        date = datetime(*date[:6])
+        date = datetime.datetime(*date[:6])
 
     # Ugly heuristic: if the date is more than 4 weeks in the future, we got the year wrong.
     # Rather then this, we would like to see parsedatetime patched so we can tell it to prefer
     # past dates
-    dt = datetime.now() - date
+    dt = datetime.datetime.now() - date
     if dt.days < -28 and not year_present:
         date = date.replace(date.year - 1)
     return date
